@@ -106,15 +106,15 @@ class PrivateBucket(
         block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
         bucket_key_enabled: typing.Optional[builtins.bool] = None,
         bucket_name: typing.Optional[builtins.str] = None,
-        cors: typing.Optional[typing.Sequence[aws_cdk.aws_s3.CorsRule]] = None,
+        cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
         encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         enforce_ssl: typing.Optional[builtins.bool] = None,
         event_bridge_enabled: typing.Optional[builtins.bool] = None,
-        intelligent_tiering_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IntelligentTieringConfiguration]] = None,
-        inventories: typing.Optional[typing.Sequence[aws_cdk.aws_s3.Inventory]] = None,
-        lifecycle_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.LifecycleRule]] = None,
-        metrics: typing.Optional[typing.Sequence[aws_cdk.aws_s3.BucketMetrics]] = None,
+        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+        inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
         object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
@@ -124,8 +124,8 @@ class PrivateBucket(
         versioned: typing.Optional[builtins.bool] = None,
         website_error_document: typing.Optional[builtins.str] = None,
         website_index_document: typing.Optional[builtins.str] = None,
-        website_redirect: typing.Optional[aws_cdk.aws_s3.RedirectTarget] = None,
-        website_routing_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.RoutingRule]] = None,
+        website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -231,15 +231,15 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
         bucket_key_enabled: typing.Optional[builtins.bool] = None,
         bucket_name: typing.Optional[builtins.str] = None,
-        cors: typing.Optional[typing.Sequence[aws_cdk.aws_s3.CorsRule]] = None,
+        cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
         encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
         enforce_ssl: typing.Optional[builtins.bool] = None,
         event_bridge_enabled: typing.Optional[builtins.bool] = None,
-        intelligent_tiering_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_s3.IntelligentTieringConfiguration]] = None,
-        inventories: typing.Optional[typing.Sequence[aws_cdk.aws_s3.Inventory]] = None,
-        lifecycle_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.LifecycleRule]] = None,
-        metrics: typing.Optional[typing.Sequence[aws_cdk.aws_s3.BucketMetrics]] = None,
+        intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+        inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+        lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+        metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
         object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
         public_read_access: typing.Optional[builtins.bool] = None,
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
@@ -249,8 +249,8 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         versioned: typing.Optional[builtins.bool] = None,
         website_error_document: typing.Optional[builtins.str] = None,
         website_index_document: typing.Optional[builtins.str] = None,
-        website_redirect: typing.Optional[aws_cdk.aws_s3.RedirectTarget] = None,
-        website_routing_rules: typing.Optional[typing.Sequence[aws_cdk.aws_s3.RoutingRule]] = None,
+        website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+        website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param access_control: Specifies a canned ACL that grants predefined permissions to the bucket. Default: BucketAccessControl.PRIVATE
@@ -280,7 +280,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
         if isinstance(website_redirect, dict):
-            website_redirect = aws_cdk.aws_s3.RedirectTarget(**website_redirect)
+            website_redirect = RedirectTarget(**website_redirect)
         if __debug__:
             type_hints = typing.get_type_hints(PrivateBucketProps.__init__)
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
